---
description: >-
  Change log of Discord Extreme List API wrapper in python, if you need help, do
  not hesitate to join the DEL server: https://discord.gg/WeCer3J
---

# Change Log

## 1.0.0

### Initial release

* The initial release of DEL.py

## 1.0.1

### Fixed

* The error that got raised when returning the data from the API

## 1.1.0

### Added

* Automatic loop to post the data to the API
* Better control over rate-limit, you now shouldn't get rate-limited even if you tried to with the package
* Logger which you can access through the logging module called "del.py"
* Better error handler

### Changed

* Format of the errors that get raised

